commit ca4ce9f8722613118da634be131cf7fdd9fca552
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Sat Feb 21 00:01:11 2026 +0700

    update docs

commit 8c1cd9fc7d8d5dea8b30d84ebf5ccff9da261499
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Sat Feb 21 00:01:00 2026 +0700

    update typing

commit 482406b35941b17f39d10bb3a6e50d75eea442a9
Merge: ac27677 3c482ce
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Feb 20 23:58:48 2026 +0700

    Merge pull request #2 from alexeev-prog/dependabot/github_actions/actions/setup-python-6

commit 3c482cea22358e55c6866d9f068237a71341b8de
Merge: ab14def ac27677
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Feb 20 23:58:39 2026 +0700

    Merge branch 'main' into dependabot/github_actions/actions/setup-python-6

commit ac276777a56a1744771d1bf9d130660cd7b2196a
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Feb 20 23:58:19 2026 +0700

    update docs

commit 75df49a4cf5c33641d9fbd73ffc609e1b2636dd8
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Feb 20 23:57:27 2026 +0700

    update docs

commit 79d5e1e3b1a8b7fc1e0ac09287ad47ff1c25ee0e
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Feb 20 23:56:32 2026 +0700

    update readme

commit cefba08c660df0085bd752a4284b359873543f44
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Feb 20 23:54:23 2026 +0700

    improve CLI App UX/UI and publish package; update readme

commit 113a20855d679499c361fd3b56810c6260be2ede
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Feb 20 23:23:51 2026 +0700

    add get-network-params and ping-address commands

commit c0c74257ad27c31bef2522a541db32834c9e0444
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Feb 20 17:49:24 2026 +0700

    update docs

commit dac508e4371aec6586445fd6fa547e373a53cabf
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Feb 20 17:49:08 2026 +0700

    update tests

commit ab14defee8ebc8ba976ff67ddc1c46770b3a5ef2
Author: dependabot[bot] <49699333+dependabot[bot]@users.noreply.github.com>
Date:   Thu Feb 19 14:33:21 2026 +0000

    Bump actions/setup-python from 5 to 6
    
    Bumps [actions/setup-python](https://github.com/actions/setup-python) from 5 to 6.
    - [Release notes](https://github.com/actions/setup-python/releases)
    - [Commits](https://github.com/actions/setup-python/compare/v5...v6)
    
    ---
    updated-dependencies:
    - dependency-name: actions/setup-python
      dependency-version: '6'
      dependency-type: direct:production
      update-type: version-update:semver-major
    ...
    
    Signed-off-by: dependabot[bot] <support@github.com>

commit ef5dec057758497001394b010dcfe6c7def62f0c
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Thu Feb 19 21:32:38 2026 +0700

    create basic structure

commit d1462c8621dbffbf488084260507937dcedc6f39
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Thu Feb 19 17:57:08 2026 +0700

    Initial commit
